@@ -33,12 +33,24 @@ format_ci <- function(CI_low, CI_high, ci = 0.95, digits = 2, brackets = TRUE, w
     if (all(is.na(CI_low))) {
       width_low <- 1
     } else {
-      width_low <- max(unlist(lapply(stats::na.omit(CI_low), function(.i) nchar(as.character(.i)))))
+      width_low <- max(unlist(lapply(stats::na.omit(CI_low), function(.i) {
+        if (.i > 1e+5) {
+          6 + digits
+        } else {
+          nchar(as.character(.i))
+        }
+      })))
     }
     if (all(is.na(CI_high))) {
       width_high <- 1
     } else {
-      width_high <- max(unlist(lapply(stats::na.omit(CI_high), function(.i) nchar(as.character(.i)))))
+      width_high <- max(unlist(lapply(stats::na.omit(CI_high), function(.i) {
+        if (.i > 1e+5) {
+          6 + digits
+        } else {
+          nchar(as.character(.i))
+        }
+      })))
     }
   }
 
