@@ -4,12 +4,12 @@
 
 
 # remove NULL elements from lists
-.compact_list <- function(x) x[!sapply(x, function(i) length(i) == 0 || is.null(i) || (!is.data.frame(i) && any(i == "NULL")) || (is.data.frame(i) && nrow(i) == 0))]
+.compact_list <- function(x) x[!sapply(x, function(i) length(i) == 0 || is.null(i) || (!is.data.frame(i) && any(i == "NULL", na.rm = TRUE)) || (is.data.frame(i) && nrow(i) == 0))]
 
 
 
 # remove empty string from character
-.compact_character <- function(x) x[!sapply(x, function(i) nchar(i) == 0 || is.null(i) || any(i == "NULL"))]
+.compact_character <- function(x) x[!sapply(x, function(i) nchar(i) == 0 || is.null(i) || any(i == "NULL", na.rm = TRUE))]
 
 
 
@@ -542,3 +542,14 @@
 
   dat[, 1:(ncol(dat) - 1), drop = FALSE]
 }
+
+
+
+#' @importFrom methods slot
+.is_baysian_emmeans <- function(x){
+  if (inherits(x, "emm_list")) {
+    x <- x[[1]]
+  }
+  post.beta <- methods::slot(x, "post.beta")
+  !(all(dim(post.beta) == 1) && is.na(post.beta))
+}
