@@ -82,6 +82,7 @@ is_model <- function(x) {
       "DirichletRegModel",
       "drc",
       "emmGrid",
+      "emm_list",
       "epi.2by2",
       "ergm",
       "feglm",
@@ -127,6 +128,7 @@ is_model <- function(x) {
       "gls",
       "gmnl",
       "gmm",
+      "HLfit",
       "htest",
       "hurdle",
       "iv_robust",
@@ -150,6 +152,7 @@ is_model <- function(x) {
       "lqm",
       "lqmm",
       "lrm",
+      "maov",
       "manova",
       "MANOVA",
       "margins",
@@ -162,11 +165,13 @@ is_model <- function(x) {
       "MCMCglmm",
       "mediate",
       "merMod",
+      "merModList",
       "meta_fixed",
       "meta_random",
       "meta_ordered",
       "metaplus",
       "mipo",
+      "mira",
       "mixed",
       "mixor",
       "MixMod",
@@ -187,6 +192,7 @@ is_model <- function(x) {
       "objectiveML",
       "ols",
       "orcutt",
+      "pairwise.htest",
       "plm",
       "plmm",
       "poissonmfx",
@@ -211,6 +217,8 @@ is_model <- function(x) {
       "slm",
       "speedlm",
       "speedglm",
+      "splmm",
+      "spml",
       "stanmvreg",
       "stanreg",
       "survfit",
