@@ -108,6 +108,7 @@ supported_models <- function() {
     "glmx",
     "gls",
     "gmnl",
+    "HLfit",
     "htest",
     "hurdle",
     "iv_robust",
@@ -129,12 +130,15 @@ supported_models <- function() {
     "lrm",
     "manova",
     "MANOVA",
+    "margins",
     "maxLik",
     "mcmc",
     "MCMCglmm",
     "metaplus",
     "merMod",
+    "merModList",
     "mipo",
+    "mira",
     "mixed",
     "mixor",
     "MixMod",
