@@ -377,6 +377,12 @@ link_inverse.negbinirr <- link_inverse.logitmfx
 # Other models ----------------------------
 
 
+#' @export
+link_inverse.merModList <- function(x, ...) {
+  link_inverse.default(x[[1]], ...)
+}
+
+
 #' @export
 link_inverse.robmixglm <- function(x, ...) {
   switch(
@@ -676,6 +682,15 @@ link_inverse.mipo <- function(x, ...) {
 }
 
 
+#' @export
+link_inverse.mira <- function(x, ...) {
+  if (!requireNamespace("mice", quietly = TRUE)) {
+    stop("Package `mice` required. Please install it.", call. = FALSE)
+  }
+  link_inverse(mice::pool(x), ...)
+}
+
+
 
 
 
