@@ -725,6 +725,12 @@ model_info.averaging <- function(x, ...) {
 }
 
 
+#' @export
+model_info.merModList <- function(x, ...) {
+  model_info.default(x[[1]], ...)
+}
+
+
 #' @export
 model_info.cglm <- function(x, ...) {
   link <- parse(text = .safe_deparse(x$call))[[1]]$link
@@ -1073,8 +1079,15 @@ model_info.gamlss <- function(x, ...) {
 
 #' @export
 model_info.mipo <- function(x, ...) {
-  models <- eval(x$call$object)
-  model_info(models$analyses[[1]], ...)
+  tryCatch(
+    {
+      models <- eval(x$call$object)
+      model_info(models$analyses[[1]], ...)
+    },
+    error = function(e) {
+      NULL
+    }
+  )
 }
 
 
