@@ -1,8 +1,6 @@
 if (require("testthat") &&
   require("insight") &&
   require("quantreg")) {
-  context("insight, model_info")
-
   data(stackloss)
   m1 <-
     rq(stack.loss ~ Air.Flow + Water.Temp,
@@ -97,7 +95,7 @@ if (require("testthat") &&
     )
     expect_equal(nrow(get_parameters(m1)), 3)
     expect_equal(
-      get_parameters(m1)$parameter,
+      get_parameters(m1)$Parameter,
       c("(Intercept)", "Air.Flow", "Water.Temp")
     )
   })
