@@ -104,7 +104,7 @@ if (require("testthat") && require("insight") && require("VGAM")) {
     )
     expect_equal(nrow(get_parameters(m1)), 5)
     expect_equal(
-      get_parameters(m1)$parameter,
+      get_parameters(m1)$Parameter,
       c(
         "(Intercept)",
         "outcome2",
